@@ -11,7 +11,7 @@
 #  See accompanying file LICENSE.txt or copy at
 #      http://www.gnu.org/licenses/gpl-3.0.html
 #
-#  Website: https://www.assembla.com/spaces/pyeasydev/wiki
+#  Website: https://github.com/cokelaer/easydev
 #  Documentation: http://packages.python.org/easydev
 #
 ##############################################################################
@@ -40,9 +40,9 @@ def get_shared_directory_path(package):
     try:
         info = pkg_resources.get_distribution(package)
         location = info.location
-    except pkg_resources.DistributionNotFound, e:
+    except pkg_resources.DistributionNotFound as err:
         print("package provided (%s) not installed." % package)
-        raise(e)
+        raise
 
 
     #print("install  mode ? ")
@@ -67,7 +67,7 @@ def get_shared_directory_path(package):
             return sharedir
         # could not be found,
         sharedir = []
-        print ("could not find any share directory in %s" % package)
+        print("could not find any share directory in %s" % package)
 
     return sharedir
 
