@@ -11,7 +11,7 @@
 #  See accompanying file LICENSE.txt or copy at
 #      http://www.gnu.org/licenses/gpl-3.0.html
 #
-#  Website: https://www.assembla.com/spaces/pyeasydev/wiki
+#  Website: https://github.com/cokelaer/easydev
 #  Documentation: http://packages.python.org/easydev
 #
 ##############################################################################
@@ -19,9 +19,24 @@
 """toolkit to ease development"""
 import subprocess
 
-
 __all__ = ["shellcmd", "checkParam", "swapdict", "check_param_in_list",
-    "check_range"]
+    "check_range", "precision", "AttrDict"]
+
+
+def precision(data, digit=2):
+    """Return the value with only 2 digits
+
+    ::
+
+        >>> precision(2.123)
+        2.12
+        >>> precision(2123, digit=-2)
+        2100
+
+    """
+    data = int(data*pow(10, digit))
+    data /= pow(10., digit)
+    return data
 
 
 def check_range(value, a, b, strict=False):
@@ -38,12 +53,12 @@ def check_range(value, a, b, strict=False):
         >>> check_range(1,0, 2)
 
     """
-    if strict == True:
+    if strict is True:
         if value <= a:
             raise ValueError(" {} must be greater (or equal) than {}".format(value, a))
         if value >= b:
             raise ValueError(" {} must be less (or less) than {}".format(value, b))
-    elif strict == False:
+    elif strict is False:
         if value < a:
             raise ValueError(" {} must be greater than {}".format(value, a))
         if value > b:
@@ -68,8 +83,9 @@ def check_param_in_list(param, valid_values, name=None):
         check_param_in_list(1, [1,2,3])
         check_param_in_list(mode, ["on", "off"])
     """
-    if isinstance(valid_values, list) == False:
-        raise TypeError("the valid_values second argument must be a list of valid values")
+    if isinstance(valid_values, list) is False:
+
+        raise TypeError("the valid_values second argument must be a list of valid values. {0} was provided.".format(valid_values))
 
     if param not in valid_values:
         if name:
@@ -105,15 +121,14 @@ def shellcmd(cmd, show=False, verbose=False):
             raise Exception(error)
 
         if verbose == True:
-            print output
+            print(output)
 
         return output
-    except Exception, err:
+    except Exception as err:
         #if verbose: print e
         raise Exception("Error:: Command (%s) failed. Error message is %s" % (cmd, err))
 
 
-
 def swapdict(dic, check_ambiguity=True):
     """Swap keys for values in a dictionary
 
@@ -129,3 +144,27 @@ def swapdict(dic, check_ambiguity=True):
         assert len(set(dic.keys())) == len(set(dic.values())), "values is not a set. ambiguities for keys."
     return dict(zip(dic.values(), dic.keys()))
 
+
+class AttrDict(dict):
+    """dictionary-like object that exposes its keys as attributes.
+
+    You can add values as attribute, or with ['key'] syntax
+
+    .. doctest::
+
+        >>> from easydev import AttrDict
+        >>> a = AttrDict('value': 1)
+        >>> a.value
+        1
+        >>>
+        >>> a.unit = 'meter'
+        >>> a.keys()
+        ['value', 'meter']
+
+
+    """
+    def __init__(self, **kwargs):
+        dict.__init__(self, kwargs)
+        self.__dict__ = self
+
+
